@@ -22,8 +22,8 @@ import functools
 import gaupol
 import os
 import re
-_ = aeidon.i18n._
 
+from aeidon.i18n   import _, n_
 from gi.repository import Gdk
 from gi.repository import Gtk
 
@@ -57,21 +57,23 @@ class SearchDialog(gaupol.BuilderDialog):
     :ivar _was_next: ``True`` if the last search was "next", else ``False``
     """
 
-    _widgets = ("all_radio",
-                "current_radio",
-                "ignore_case_check",
-                "main_check",
-                "next_button",
-                "overlay",
-                "pattern_combo",
-                "previous_button",
-                "regex_check",
-                "replace_all_button",
-                "replace_button",
-                "replacement_combo",
-                "search_vbox",
-                "text_view",
-                "tran_check")
+    _widgets = (
+        "all_radio",
+        "current_radio",
+        "ignore_case_check",
+        "main_check",
+        "next_button",
+        "overlay",
+        "pattern_combo",
+        "previous_button",
+        "regex_check",
+        "replace_all_button",
+        "replace_button",
+        "replacement_combo",
+        "search_vbox",
+        "text_view",
+        "tran_check",
+    )
 
     def __init__(self, parent, application):
         """Initialize a :class:`SearchDialog` instance."""
@@ -83,14 +85,15 @@ class SearchDialog(gaupol.BuilderDialog):
         self._match_row = None
         self._match_span = None
         self.max_history = 10
-        self._pattern_entry = self._pattern_combo.get_child()
+        self._pattern_entry = None
         self.patterns = []
-        self._replacement_entry = self._replacement_combo.get_child()
+        self._replacement_entry = None
         self.replacements = []
         self._statuslabel = gaupol.FloatingLabel()
         self._was_next = None
         self._read_history("patterns")
         self._read_history("replacements")
+        self._init_dialog(parent)
         self._init_text_view()
         self._init_pattern_combo()
         self._init_replacement_combo()
@@ -101,9 +104,6 @@ class SearchDialog(gaupol.BuilderDialog):
         self._overlay.add_overlay(self._statuslabel)
         self._overlay.show_all()
         self._statuslabel.set_text(None)
-        self._dialog.set_transient_for(parent)
-        self._dialog.set_type_hint(Gdk.WindowTypeHint.NORMAL)
-        self._dialog.set_default_response(Gtk.ResponseType.CLOSE)
 
     def _add_pattern_to_history(self):
         """Add current pattern to the pattern combo box."""
@@ -184,6 +184,13 @@ class SearchDialog(gaupol.BuilderDialog):
             return gaupol.targets.ALL
         raise ValueError("Invalid target radio state")
 
+    def _init_dialog(self, parent):
+        """Initialize the dialog."""
+        self.add_button(_("_Help"), Gtk.ResponseType.HELP)
+        self._dialog.set_default_response(Gtk.ResponseType.CLOSE)
+        self._dialog.set_transient_for(parent)
+        self.set_modal(False)
+
     def _init_keys(self):
         """Initialize keyboard shortcuts."""
         accel_group = Gtk.AccelGroup()
@@ -201,6 +208,7 @@ class SearchDialog(gaupol.BuilderDialog):
         for pattern in self.patterns:
             store.append((pattern,))
         self._pattern_combo.set_entry_text_column(0)
+        self._pattern_entry = self._pattern_combo.get_child()
 
     def _init_replacement_combo(self):
         """Initialize the replacement combo box."""
@@ -209,6 +217,7 @@ class SearchDialog(gaupol.BuilderDialog):
         for replacement in self.replacements:
             store.append((replacement,))
         self._replacement_combo.set_entry_text_column(0)
+        self._replacement_entry = self._replacement_combo.get_child()
 
     def _init_sensitivities(self):
         """Initialize widget sensitivities."""
@@ -232,8 +241,16 @@ class SearchDialog(gaupol.BuilderDialog):
 
     def _init_text_view(self):
         """Initialize the text view."""
+        with aeidon.util.silent(AttributeError):
+            # Top and bottom margins available since GTK+ 3.18.
+            self._text_view.set_top_margin(6)
+            self._text_view.set_bottom_margin(6)
         gaupol.util.prepare_text_view(self._text_view)
-        gaupol.util.scale_to_size(self._text_view, nchar=60, nlines=4)
+        gaupol.util.scale_to_size(self._text_view,
+                                  nchar=55,
+                                  nlines=6,
+                                  font="custom")
+
         text_buffer = self._text_view.get_buffer()
         text_buffer.connect("changed", self._on_text_buffer_changed)
 
@@ -288,8 +305,9 @@ class SearchDialog(gaupol.BuilderDialog):
         # that no longer exists. All search dialog's data changing methods
         # need to be wrapped to disable this handling of application's
         # page-changed signals.
-        if self._handle_page_changes and self._match_page is not None:
-            self._reset_properties()
+        if self._handle_page_changes:
+            if self._match_page is not None:
+                self._reset_properties()
 
     def _on_current_radio_toggled(self, radio_button):
         """Save search target."""
@@ -449,10 +467,10 @@ class SearchDialog(gaupol.BuilderDialog):
                 self._show_regex_error_dialog_replacement(str(error))
                 break
         self._reset_properties()
-        self._statuslabel.flash_text(aeidon.i18n.ngettext(
-                "Found and replaced {:d} occurence",
-                "Found and replaced {:d} occurences",
-                count).format(count))
+        self._statuslabel.flash_text(n_(
+            "Found and replaced {:d} occurence",
+            "Found and replaced {:d} occurences",
+            count).format(count))
 
     def _reset_properties(self):
         """Reset search properties to defaults."""
@@ -559,7 +577,7 @@ class SearchDialog(gaupol.BuilderDialog):
     def _write_history(self, name):
         """Write history to file of type `name`."""
         directory = os.path.join(aeidon.CONFIG_HOME_DIR, "search")
-        with aeidon.util.silent(OSError):
+        with aeidon.util.silent(OSError, tb=True):
             path = os.path.join(directory, "{}.history".format(name))
             history = getattr(self, name)
             text = "\n".join(history) + "\n"
